@@ -3,12 +3,13 @@
 package Test::Regexp::Pattern;
 
 our $DATE = '2018-09-10'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
 use warnings;
 
+use Regexp::Pattern qw(re);
 use File::Spec;
 use Test::Builder;
 use Test::More ();
@@ -27,7 +28,7 @@ sub import {
 }
 
 sub _test_regexp_pattern {
-    my ($re, $opts) = @_;
+    my ($re, $fqname, $opts) = @_;
     my $ok = 1;
 
   GENERAL: {
@@ -47,14 +48,14 @@ sub _test_regexp_pattern {
                 sub {
                     $Test->ok(defined($eg->{str}), 'example provides string to match') or do {
                         $ok = 0;
-                        next EXAMPLE;
+                        return;
                     };
-                    my $pat;
+                    my %args;
                     if ($eg->{gen_args}) {
-                        $pat = $re->{gen}->(%{ $eg->{gen_args} });
-                    } else {
-                        $pat = $re->{pat};
+                        $args{$_} = $eg->{gen_args}{$_} for keys %{$eg->{gen_args}};
                     }
+
+                    my $pat = re($fqname, %args);
                     my $actual_match = $eg->{str} =~ $pat ? 1:0;
                     if (ref $eg->{matches} eq 'ARRAY') {
                         my $len = @{ $eg->{matches} };
@@ -66,7 +67,7 @@ sub _test_regexp_pattern {
                         if ($should_match) {
                             $Test->ok( $actual_match, 'string should match') or do {
                                 $ok = 0;
-                                next EXAMPLE;
+                                return;
                             };
                             Test::More::is_deeply(\@actual_matches, $eg->{matches}, 'matches') or do {
                                   $Test->diag($Test->explain(\@actual_matches));
@@ -75,7 +76,7 @@ sub _test_regexp_pattern {
                         } else {
                             $Test->ok(!$actual_match, 'string should not match') or do {
                                 $ok = 0;
-                                next EXAMPLE;
+                                return;
                             };
                         }
                     } elsif (ref $eg->{matches} eq 'HASH') {
@@ -84,7 +85,7 @@ sub _test_regexp_pattern {
                         if ($should_match) {
                             $Test->ok( $actual_match, 'string should match') or do {
                                 $ok = 0;
-                                next EXAMPLE;
+                                return;
                             };
                             Test::More::is_deeply(\%actual_matches, $eg->{matches}, 'matches') or do {
                                   $Test->diag($Test->explain(\%actual_matches));
@@ -93,19 +94,19 @@ sub _test_regexp_pattern {
                         } else {
                             $Test->ok(!$actual_match, 'string should not match') or do {
                                 $ok = 0;
-                                next EXAMPLE;
+                                return;
                             };
                         }
                     } else {
                         if ($eg->{matches}) {
                             $Test->ok( $actual_match, 'string should match') or do {
                                 $ok = 0;
-                                next EXAMPLE;
+                                return;
                             };
                         } else {
                             $Test->ok(!$actual_match, 'string should not match') or do {
                                 $ok = 0;
-                                next EXAMPLE;
+                                return;
                             };
                         }
                     }
@@ -132,16 +133,25 @@ sub regexp_patterns_in_module_ok {
             (my $modulepm = "$module.pm") =~ s!::!/!g;
             require $modulepm;
 
+            my $prefix = '';
+            if ($module =~ /\ARegexp::Pattern::(.+)/) {
+                $prefix = "$1\::";
+            } else {
+                goto L1;
+            }
+
             for my $name (sort keys %{ "$module\::RE" }) {
                 my $re = ${"$module\::RE"}{$name};
                 $has_tests++;
                 $Test->subtest(
-                    "pattern $name",
+                    "pattern $prefix$name",
                     sub {
-                        _test_regexp_pattern($re, \%opts) or $ok = 0;
+                        _test_regexp_pattern($re, "$prefix$name", \%opts) or $ok = 0;
                     },
                 ) or $ok = 0;
             }
+
+          L1:
             unless ($has_tests) {
                 $Test->ok(1);
                 $Test->diag("No regexp patterns to test");
@@ -251,7 +261,7 @@ Test::Regexp::Pattern - Test Regexp::Pattern patterns
 
 =head1 VERSION
 
-This document describes version 0.002 of Test::Regexp::Pattern (from Perl distribution Test-Regexp-Pattern), released on 2018-09-10.
+This document describes version 0.003 of Test::Regexp::Pattern (from Perl distribution Test-Regexp-Pattern), released on 2018-09-10.
 
 =head1 SYNOPSIS
 
